@@ -11,6 +11,8 @@ def update_bind_status(database, bind_address, bind_status):
 
     if bind_status not in [CREATING, CREATED]:
         bind_status = ERROR
+    else:
+        bind_status = CREATED
 
     bind = DatabaseBind.objects.get(database= database, bind_address= bind_address)
     instances = database.infra.instances.all()
